Device

Struct Device 

pub struct Device(/* private fields */);
Available on Android or Linux only.

Implementations

Source

impl Device

pub fn open<P: AsRef<Path>>(path: P) -> Result<Self>

Examples found in repository?
examples/device.rs (line 6)
5fn print_info<P: AsRef<Path>>(path: P) -> Result<()> {
6	let mut device = Device::open(path)?;
7
8	println!("{device:#?}");
9	println!("\t{:?}", device.get_physical_address()?);
10	println!("\t{:?}", device.get_report_descriptor()?);
11	println!("\t{:?}", device.get_raw_unique()?);
12
13	Ok(())
14}
Source

impl Device

pub fn get_feature_report<T>(&mut self, report_id: u8) -> Result<T>

Request a feature report using HIDIOCGFEATURE ioctl.

pub unsafe fn get_feature_report_with_size<T>( &mut self, report_id: u8, size: usize, ) -> Result<T>

Available on crate feature unsafe_reports only.

Request a feature report using HIDIOCGFEATURE ioctl with specific size.

Safety

Calling this function with size > size_of::<T>() is undefined behaviour.

pub fn get_input_report<T>(&mut self, report_id: u8) -> Result<T>

Request an input report using HIDIOCGINPUT ioctl.

pub unsafe fn get_input_report_with_size<T>( &mut self, report_id: u8, size: usize, ) -> Result<T>

Available on crate feature unsafe_reports only.

Request an input report using HIDIOCGINPUT ioctl with specific size.

Safety

Calling this function with size > size_of::<T>() is undefined behaviour.

pub fn get_input_report_read<T>(&mut self, report_id: u8) -> Result<T>

Request an input report using read.

pub unsafe fn get_input_report_read_with_size<T>( &mut self, report_id: u8, size: usize, ) -> Result<T>

Available on crate feature unsafe_reports only.

Request an input report using read with specific size.

Safety

Calling this function with size > size_of::<T>() is undefined behaviour.

pub fn get_output_report<T>(&mut self, report_id: u8) -> Result<T>

Request an output report using HIDIOCGOUTPUT ioctl.

pub unsafe fn get_output_report_with_size<T>( &mut self, report_id: u8, size: usize, ) -> Result<T>

Available on crate feature unsafe_reports only.

Request an output report using HIDIOCGOUTPUT ioctl with specific size.

Safety

Calling this function with size > size_of::<T>() is undefined behaviour.

pub fn get_physical_address(&mut self) -> Result<String>

Examples found in repository?
examples/device.rs (line 9)
5fn print_info<P: AsRef<Path>>(path: P) -> Result<()> {
6	let mut device = Device::open(path)?;
7
8	println!("{device:#?}");
9	println!("\t{:?}", device.get_physical_address()?);
10	println!("\t{:?}", device.get_report_descriptor()?);
11	println!("\t{:?}", device.get_raw_unique()?);
12
13	Ok(())
14}
pub fn get_raw_info(&mut self) -> Result<RawInfo>

pub fn get_raw_name(&mut self) -> Result<String>

pub fn get_raw_unique(&mut self) -> Result<String>

Examples found in repository?
examples/device.rs (line 11)
5fn print_info<P: AsRef<Path>>(path: P) -> Result<()> {
6	let mut device = Device::open(path)?;
7
8	println!("{device:#?}");
9	println!("\t{:?}", device.get_physical_address()?);
10	println!("\t{:?}", device.get_report_descriptor()?);
11	println!("\t{:?}", device.get_raw_unique()?);
12
13	Ok(())
14}
pub fn get_report_descriptor(&mut self) -> Result<Vec<u8>>

Examples found in repository?
examples/device.rs (line 10)
5fn print_info<P: AsRef<Path>>(path: P) -> Result<()> {
6	let mut device = Device::open(path)?;
7
8	println!("{device:#?}");
9	println!("\t{:?}", device.get_physical_address()?);
10	println!("\t{:?}", device.get_report_descriptor()?);
11	println!("\t{:?}", device.get_raw_unique()?);
12
13	Ok(())
14}
pub fn send_feature_report<T>(&mut self, report: &T) -> Result<()>

Send a feature report using HIDIOCSFEATURE ioctl.

pub unsafe fn send_feature_report_with_size<T>( &mut self, report: &T, size: usize, ) -> Result<()>

Available on crate feature unsafe_reports only.

Send a feature report using HIDIOCSFEATURE ioctl with specific size.

Safety

Calling this function with size > size_of::<T>() is undefined behaviour.

pub fn send_input_report<T>(&mut self, report: &T) -> Result<()>

Send an input report using HIDIOCSINPUT ioctl.

pub unsafe fn send_input_report_with_size<T>( &mut self, report: &T, size: usize, ) -> Result<()>

Available on crate feature unsafe_reports only.

Send an input report using HIDIOCSINPUT ioctl with specific size.

Safety

Calling this function with size > size_of::<T>() is undefined behaviour.

pub fn send_output_report<T>(&mut self, report: &T) -> Result<()>

Send an output report using HIDIOCSOUTPUT ioctl.

pub unsafe fn send_output_report_with_size<T>( &mut self, report: &T, size: usize, ) -> Result<()>

Available on crate feature unsafe_reports only.

Send an output report using HIDIOCSOUTPUT ioctl with specific size.

Safety

Calling this function with size > size_of::<T>() is undefined behaviour.

pub fn send_output_report_write<T>(&mut self, report: &T) -> Result<()>

Send an output report using write.

pub unsafe fn send_output_report_write_with_size<T>( &mut self, report: &T, size: usize, ) -> Result<()>

Available on crate feature unsafe_reports only.

Send an output report using write with specific size.

Safety

Calling this function with size > size_of::<T>() is undefined behaviour.